THE BOOST MPL LIBRARY: Acknowledgements

Front Page / Acknowledgements

# Acknowledgements

Many, many people in one or another way contributed to the library development. The list below is known to be incomplete and needs updating! We sincerely promise to fix it in the near feature.

For bug reports, patches, suggestions and insightful discussions, our thanks go to:

- John Bandela
- Fernando Cacciola
- Peter Dimov
- Eric Friedman
- Arnaldur Gylfason
- David B. Held
- Vesa Karvonen
- Mat Marcus
- Hamish Mackenzie
- Paul Mensonides
- Emily Winch